pyramid_fullauth
================

.. image:: https://img.shields.io/pypi/v/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/pyramid_fullauth/badge/?version=v1.0.0
    :target: https://readthedocs.org/projects/pyramid_fullauth/?badge=v1.0.0
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/dm/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/wheel/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Wheel Status

.. image:: https://img.shields.io/pypi/l/pyramid_fullauth.svg
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: License

Pyramid fullauth's provides full user registration and management functionality for
`pyramid <http://docs.pylonsproject.org/en/latest/docs/pyramid.html>`_ based web applications.

Package resources
-----------------

* Bug tracker: https://github.com/fizyk/pyramid_fullauth/issues
* Documentation: http://pyramid-fullauth.readthedocs.org/
* PyPI: https://pypi.python.org/pypi/pyramid_fullauth


Tests
-----

You'll need: packages defined in extra_requires[tests] to run tests, and then:

``py.test``
